#!/usr/bin/python3

import gi, os, sys

gi.require_version('Gtk', '3.0')

from gi.repository import Gtk, Gdk, GLib, Gio, GObject, GdkPixbuf

from webengine.gtk3 import WebEngine, create_setting, create_hmr_server, create_bridge

from _window import Window
from _docker import Docker


APP_ID = 'fun.wkit.dooke'
__dir__ = os.path.dirname(os.path.realpath(__file__))

web_root = os.path.join(__dir__, './webapp')
home_dir = os.getenv('HOME')
client = Docker()


class Application(Gtk.Application):
  def __init__(self):

    Gtk.Application.__init__(self, application_id = APP_ID)

    self.window = Window()

    web = WebEngine(self.window)
    web.set_root(web_root)

    if os.getenv('RUN_ENV') == 'development':
      setting = create_setting({"devtools": True})
      hmr = create_hmr_server()
      web.use(setting).use(hmr)

    bridge = create_bridge()

    web.use(bridge, self.bridge_handler)

    web.connect('quit', self.quit_all)
    web.load()

    self.window.add(web)


  def bridge_handler(self, ev, params):
    _error = None
    output = None
    print(ev, params)
    match ev:
      case 'docker':
        action = params['action']

        match action:
          case 'containers':
            all = params['all'] or False
            output = client.containers(all)

          case 'images':
            output = client.images()

          case 'rm':
            client.rm(params.get('id'))

          case 'rmi':
            client.rmi(params.get('id'))
            

    
    return (_error, output)


  def do_activate(self):

    self.set_app_menu(None)
    self.set_menubar(None)

    self.add_window(self.window)
    self.window.show_all()


  def quit_all(self, widget):
    self.remove_window(self.window)




if __name__ == "__main__":    
  try:
    app = Application()
    app.run(sys.argv)
  except Exception as err:
    print(err)

